@@ -6,7 +6,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 
 my %TAG_TEMPLATE;
 $TAG_TEMPLATE{css} = [qw(link rel stylesheet href)];
@@ -79,7 +79,7 @@ sub process {
     for my $pipe (@{$self->{pipes}}) {
       next unless $pipe->can($method);
       local $pipe->{topic} = $topic;
-      diag '%s->%s($assets)', ref $pipe, $method if DEBUG;
+      diag '%s->%s("%s")', ref $pipe, $method, $topic if DEBUG;
       $pipe->$method($assets);
       push @{$self->{asset_paths}}, $_->path for @$assets;
     }
@@ -88,7 +88,7 @@ sub process {
   $self->_app->log->debug(qq(Processed asset "$topic".));
   $self->{by_checksum}{$_->checksum} = $_ for @$assets;
   $self->{by_topic}{$topic} = $assets;
-  $self->route;    # make sure we add the route to the app
+  $self->route;    # make sure we add the asset route to the app
   $self;
 }
 
@@ -117,7 +117,8 @@ sub register {
     $app->helper($helper => sub { @_ == 1 ? $self : $self->_render_tags(@_) });
   }
   else {
-    $app->log->warn('Loading DEPRECATED Mojolicious::Plugin::AssetPack::Backcompat.');
+    $app->log->warn(
+      'https://metacpan.org/release/Mojolicious-Plugin-AssetPack-Backcompat is required');
     Test::More::diag("Loading DEPRECATED Mojolicious::Plugin::AssetPack::Backcompat.")
       if $ENV{HARNESS_ACTIVE} and UNIVERSAL::can(qw(Test::More diag));
     require Mojolicious::Plugin::AssetPack::Backcompat;
@@ -134,8 +135,8 @@ sub _correct_mode {
   while ($args =~ /\[(\w+)([!=]+)([^\]]+)/g) {
     my $v = $1 eq 'minify' ? $self->minify : $self->_app->$1;
     diag "Checking $1: $v $2 $3" if DEBUG == 2;
-    return 0 if $2 eq '==' and $v ne $3;
     return 0 if $2 eq '!=' and $v eq $3;
+    return 0 if $2 ne '!=' and $v ne $3;    # default to testing equality
   }
 
   return 1;
@@ -246,7 +247,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.19
+1.20
 
 =head1 SYNOPSIS
 
@@ -288,7 +289,7 @@ pipes:
 
   $app->plugin(AssetPack => {pipes => [...]});
 
-The old API will not be maintained and slowly deprecated.
+The old API require L<Mojolicious::Plugin::AssetPack::Backcompat> to be installed.
 
 =head1 DESCRIPTION
 
